@@ -1,6 +1,6 @@
 package Getopt::EX::Hashed;
 
-our $VERSION = '0.9913';
+our $VERSION = '0.9914';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Getopt::EX::Hashed - Hash store object automation
 
 =head1 VERSION
 
-Version 0.9913
+Version 0.9914
 
 =head1 SYNOPSIS
 
@@ -20,7 +20,8 @@ Version 0.9913
   use Getopt::EX::Hashed;
   has start  => ( spec => "=i s begin", default => 1 );
   has end    => ( spec => "=i e" );
-  has file   => ( spec => "=s", is => 'rw' );
+  has file   => ( spec => "=s", is => 'rw', re => qr/^(?!\.)/ );
+  has score  => ( spec => '=i', min => 0, max => 100 );
   has answer => ( spec => '=i', must => sub { $_[1] == 42 } );
   no  Getopt::EX::Hashed;
 
@@ -201,13 +202,11 @@ sub _optspec {
 	$action and ref $action ne 'CODE'
 	    and die "$name->action: not a coderef.\n";
 	my $dest = do {
-	    if (my $must = $m->{must}) {
-		ref $must ne 'CODE'
-		    and die "$name->must: not a coderef.\n";
+	    if (my $is_valid = _validator($m)) {
 		$action ||= \&_generic_setter;
 		sub {
 		    local $_ = $obj;
-		    &$must or die "@_: invalid value.\n";
+		    &$is_valid or die "@_: invalid option/value.\n";
 		    &$action;
 		};
 	    }
@@ -226,6 +225,18 @@ sub _optspec {
     } @spec;
 }
 
+sub _validator {
+    my $m = shift;
+    grep { defined } @{$m}{qw(min max re must)} or return undef;
+    sub {
+	defined $m->{min}  and $_[-1] <  $m->{min} and return 0;
+	defined $m->{max}  and $_[-1] >  $m->{max} and return 0;
+	defined $m->{re}   and $_[-1] !~ $m->{re}  and return 0;
+	defined $m->{must} and not &{$m->{must}}   and return 0;
+	return 1;
+    }
+}
+
 sub _generic_setter {
     my $dest = $_->{$_[0]};
     (ref $dest eq 'ARRAY') ? do { push @$dest, $_[1] } :
@@ -291,7 +302,7 @@ In the current implementation, using B<Getopt::Long>, or compatible
 module such as B<Getopt::EX::Long> is assumed.  It is configurable,
 but no other module is supported now.
 
-Accessor methods are automatically generated when appropiate parameter
+Accessor methods are automatically generated when appropriate parameter
 is given.
 
 =head1 FUNCTION
@@ -317,7 +328,7 @@ Following parameters are available.
 
 =item B<is> => I<ro> | I<rw>
 
-If an B<is> parameter is given, accessor method for the member,
+If an C<is> parameter is given, accessor method for the member,
 read-only for I<ro> and read-write for I<rw>, is generated.
 
 =item B<spec> => I<string>
@@ -353,7 +364,7 @@ string as a value.  Otherwise, it is not considered as an option.
 =item B<alias> => I<string>
 
 Additional alias names can be specified by B<alias> parameter too.
-There is no difference with ones in B<spec> parameter.
+There is no difference with ones in C<spec> parameter.
 
 =item B<default> => I<value>
 
@@ -362,7 +373,7 @@ as C<undef>.
 
 =item B<action> => I<coderef>
 
-Parameter B<action> takes code reference which is called to process
+Parameter C<action> takes code reference which is called to process
 the option.  When called, hash object is passed through C<$_>.
 
     has [ qw(left right both) ] => spec => '=i';
@@ -378,21 +389,37 @@ spec parameter does not matter and not required.
         push @{$_->{ARGV}}, $_[0];
     };
 
-In fact, B<default> parameter takes code reference too.  It is stored
+In fact, C<default> parameter takes code reference too.  It is stored
 in the hash object and the code works almost same.  But the hash value
 can not be used for option storage.
 
+=back
+
+Following parameters are all for data validation.  First C<must> is a
+generic validator and can implement anything.  Others are shorthand
+for common rules.
+
+=over 7
+
 =item B<must> => I<coderef>
 
-Parameter B<must> takes a code reference to validate option values.
-It takes same arguments as B<action> and returns boolean.  With next
+Parameter C<must> takes a code reference to validate option values.
+It takes same arguments as C<action> and returns boolean.  With next
 example, option B<--answer> takes only 42 as a valid value.
 
     has answer =>
         spec => '=i',
         must => sub { $_[1] == 42 };
 
-Can be used with B<action> parameter.
+=item B<min> => I<number>
+
+=item B<max> => I<number>
+
+Set the minimum and maximum limit for the argument.
+
+=item B<re> => qr/I<pattern>/
+
+Set the required regular expression pattern for the argument.
 
 =back
 
@@ -404,10 +431,6 @@ Can be used with B<action> parameter.
 
 Class method to get initialized hash object.
 
-=item B<configure>
-
-There should be some configurable variables, but not fixed yet.
-
 =item B<getopt>
 
 Call C<GetOptions> function defined in caller's context with
@@ -452,6 +475,57 @@ This is almost equivalent to the next code:
     my $obj = Getopt::EX::Hashed->new;
     Getopt::EX::Hashed->reset;
 
+=item B<configure> B<label> => I<value>, ...
+
+There are following configuration parameters.
+
+=over 7
+
+=item B<LOCK_KEYS> (default: 1)
+
+Lock hash keys.  This avoids accidental access to non-existing hash
+entry.
+
+=item B<REPLACE_UNDERSCORE> (default: 1)
+
+Produce alias with underscores replaced by dash.
+
+=item B<REMOVE_UNDERSCORE> (default: 0)
+
+Produce alias with underscores removed.
+
+=begin comment
+
+=item B<RESET_AFTER_NEW> (default: 0)
+
+Reset class information after new.
+
+=end comment
+
+=item B<GETOPT> (default: 'GetOptions')
+
+Set function name called from C<getopt> method.
+
+=item B<ACCESSOR_PREFIX>
+
+When specified, it is prepended to the member name to make accessor
+method.  If C<ACCESSOR_PREFIX> is defined as C<opt_>, accessor for
+member C<file> will be C<opt_file>.
+
+=item B<DEFAULT>
+
+Set default parameters.  At the call for C<has>, DEFAULT parameters
+are inserted before argument parameters.  So if both include same
+parameter, later one in argument list has precedence.  Incremental
+call with C<+> is not affected.
+
+Typical use of DEFAULT is C<is> to prepare accessor method for all
+following hash entries.  Declare C<< is => '' >> to reset.
+
+    Getopt::EX::Hashed->configure(is => 'ro');
+
+=back
+
 =back
 
 =head1 SEE ALSO
@@ -478,3 +552,7 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
+
+#  LocalWords:  Accessor param ro rw accessor undef coderef qw ARGV
+#  LocalWords:  validator qr GETOPT GetOptions getopt obj optspec foo
+#  LocalWords:  Kazumasa Utashiro min
